@@ -85,7 +85,7 @@ def makeIndividualData(file,tags):
     individual_data.y = labels
     individual_data.text = text
     individual_data.img_id = file.index
-    print(f'File {file.index} --> Success')
+    print(f'File {file.index} --> Success', flush=True)
     return individual_data
 
 def getDataForUniquePrediction(json,tags):
