@@ -8,17 +8,18 @@ def GetJsonFromFile(jsonPath):
     f.close()
     return result
 
-def ConvertJsonToDocumentsObjects(jsonPath):
-    json = GetJsonFromFile(jsonPath)
+def ConvertJsonToDocumentsObjects(json):
     listOfDocuments = []
     for i in json:
         index = i["Index"]
+        width = i["Width"]
+        height = i["Height"]
         nodes = i["Nodes"]
         listOfNodes = []
         for j in nodes:
             node = Node(XMin=j["XMin"], YMin=j["YMin"], XMax=j["XMax"], YMax=j["YMax"], Object= j["Object"], Tag=j["Tag"])
             listOfNodes.append(node)
-        doc = Document(index=index, nodes=listOfNodes)
+        doc = Document(index=index, width=width, height=height, nodes=listOfNodes)
         listOfDocuments.append(doc)
     return listOfDocuments
 
